// Copyright © 2019 Richard Kettlewell.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
#include <config.h>
#include "rsbackup.h"
#include "BackupPolicy.h"

/** @brief The @c always backup policy; backups are made at every opportunity.
 */
class BackupPolicyAlways: public BackupPolicy {
public:
  BackupPolicyAlways(): BackupPolicy("always") {}

  void validate(const Volume *) const override {}

  bool backup(const Volume *, const Device *) const override {
    return true;
  }

} backup_always;
